@@ -25,7 +25,7 @@ class DjangoAllauth(Feature):
             # 'allauth.socialaccount.providers.angellist',
             # 'allauth.socialaccount.providers.bitly',
             # 'allauth.socialaccount.providers.dropbox',
-            'allauth.socialaccount.providers.facebook',
+            #'allauth.socialaccount.providers.facebook',
             # 'allauth.socialaccount.providers.feedly',
             # 'allauth.socialaccount.providers.github',
             # 'allauth.socialaccount.providers.google',
